@@ -9,7 +9,9 @@ from abc import ABC, abstractmethod
 from . import Loggable
 from contextlib import contextmanager
 import logging
+from opentelemetry import trace
 from opentelemetry.trace.propagation.tracecontext import TraceContextTextMapPropagator
+from otel_extensions import instrumented
 
 __all__ = ["BaseProducer", "BlockingProducer", "PikaChannel", "ConnectionError"]
 
@@ -77,14 +79,22 @@ class BaseProducer(ABC, Loggable):
     def channel(self) -> PikaChannel:
         pass
 
+    @instrumented
     def queue_declare(
         self,
         queue,
         **kwargs,
     ):
+        span = trace.get_current_span()
+        span.set_attribute("queue", queue)
         self.channel.queue_declare(queue, **kwargs)
 
+    @instrumented
     def publish(self, exchange: str, routing_key: str, payload: dict, persistent: bool):
+        span = trace.get_current_span()
+        span.set_attribute("exchange", exchange)
+        span.set_attribute("routing_key", routing_key)
+        span.set_attribute("persistent", persistent)
         delivery_mode = (
             PERSISTENT_DELIVERY_MODE if persistent else TRANSIENT_DELIVERY_MODE
         )
